==> mastapy-14.1.0rc1-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/damping_specification.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.system_model.analyses_and_results.harmonic_analyses import _5853

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DampingSpecification")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DampingSpecification",)


class EnumWithSelectedValue_DampingSpecification(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_DampingSpecification

    A specific implementation of 'EnumWithSelectedValue' for 'DampingSpecification' types.
    """

    __qualname__ = "DampingSpecification"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_DampingSpecification]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DampingSpecification]",
    ) -> "_5853.DampingSpecification":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _5853.DampingSpecification
        """
        return _5853.DampingSpecification

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_DampingSpecification]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _5853.DampingSpecification.type_()

    @property
    def selected_value(self: "Self") -> "_5853.DampingSpecification":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.DampingSpecification

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_5853.DampingSpecification]":
        """List[mastapy.system_model.analyses_and_results.harmonic_analyses.DampingSpecification]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-15.0.0b4-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/damping_specification.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.system_model.analyses_and_results.harmonic_analyses import _6018

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DampingSpecification")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DampingSpecification",)


class EnumWithSelectedValue_DampingSpecification(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_DampingSpecification

    A specific implementation of 'EnumWithSelectedValue' for 'DampingSpecification' types.
    """

    __qualname__ = "DampingSpecification"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_DampingSpecification]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DampingSpecification]",
    ) -> "_6018.DampingSpecification":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _6018.DampingSpecification
        """
        return _6018.DampingSpecification

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_DampingSpecification]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _6018.DampingSpecification.type_()

    @property
    @exception_bridge
    def selected_value(self: "Self") -> "_6018.DampingSpecification":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.DampingSpecification

        Note:
            This property is readonly.
        """
        return None

    @property
    @exception_bridge
    def available_values(self: "Self") -> "List[_6018.DampingSpecification]":
        """List[mastapy.system_model.analyses_and_results.harmonic_analyses.DampingSpecification]

        Note:
            This property is readonly.
        """
        return None
